<p align="center">
  <a href="" rel="noopener">
 <img width=200px height=200px src="https://i.imgur.com/nkMr2fl.png" alt="Project logo"></a>
</p>

<h1 align="center">Scripts</h1>

This directory contains various programs and scripts that use data fetched by
spyctl for specific purposes.  

Look at the header of each program/script for a description of what the
script does.
